CyberPot
========

CyberPot is a TCP honeypot written in python 3.

Source Code
-----------
https://github.com/najmieadnan/CyberPot

Documentation
-------------
Documentation can be found in the 'docs/' directory, or at https://cyberpot.rtfd.io

Build the docs by running 'make' in the 'docs/' directory, then viewing at 'docs/_build/html/index.html'.